@@ -3,12 +3,12 @@ package WWW::Wikipedia;
 use strict;
 use warnings;
 use Carp qw( croak );
-use CGI qw( escape );
+use URI::Escape ();
 use WWW::Wikipedia::Entry;
 
 use base qw( LWP::UserAgent );
 
-our $VERSION = '1.93';
+our $VERSION = '1.95';
 
 use constant WIKIPEDIA_URL =>
     'http://%s.wikipedia.org/w/index.php?title=%s&action=raw';
@@ -147,7 +147,7 @@ sub search {
     $self->error( undef );
 
     croak( "search() requires you pass in a string" ) if !defined( $string );
-    $string = escape( $string );
+    $string = URI::Escape::uri_escape( $string );
     my $src = sprintf( WIKIPEDIA_URL, $self->language(), $string );
 
     my $response = $self->get( $src );
@@ -180,9 +180,9 @@ sub random {
     my $response = $self->get( $src );
 
     if ( $response->is_success() ) {
-
         # get the raw version of the current url
-        $src      = $response->request->uri . '?action=raw';
+        my( $title ) = $response->request->uri =~ m{\.org/wiki/(.+)$};
+        $src      = sprintf( WIKIPEDIA_URL, $self->language(), $title );
         $response = $self->get( $src );
         return WWW::Wikipedia::Entry->new( $response->content(), $src );
     }
@@ -234,7 +234,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007 by Ed Summers
+Copyright 2003-2009 by Ed Summers
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
